spoon.spoonstream.SocketFile

Package spoon :: Module spoonstream :: Class SocketFile |
[show private | hide private]
[frames | no frames]

## Type SocketFile

    object --+
             |
            SocketFile

Simple wrapper around a socket like object that pretends to be a file. Albeit one that can't seek or tell for obvious reasons.

Method Summary
| `__init__(self, sock)`
| `close(self)`
| `read(self, cnt)`
| `write(self, data)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net